@@ -4,6 +4,8 @@
 #include <goocanvas.h>
 
 
+static GooCanvasItem *path1;
+
 static void
 setup_canvas (GtkWidget *canvas)
 {
@@ -12,7 +14,7 @@ setup_canvas (GtkWidget *canvas)
   root = goo_canvas_get_root_item (GOO_CANVAS (canvas));
 
   /* Test the simple commands like moveto and lineto: MmZzLlHhVv. */
-  path = goo_canvas_path_new (root, "M 20 20 L 40 40", NULL);
+  path1 = goo_canvas_path_new (root, "M 20 20 L 40 40", NULL);
   path = goo_canvas_path_new (root, "M30 20 l20, 20", NULL);
   path = goo_canvas_path_new (root, "M 60 20 H 80", NULL);
   path = goo_canvas_path_new (root, "M60 40 h20", NULL);
@@ -96,15 +98,41 @@ setup_canvas (GtkWidget *canvas)
 }
 
 
+static void
+move_path_clicked (GtkWidget *button, GooCanvas *canvas)
+{
+  static gint count = 0;
+
+  gchar *data;
+
+  if (count == 0)
+    data = "M130,70 L317,70";
+  else if (count == 1)
+    data = "M130,170 L317,170";
+  else
+    data = "M130,270 L317,270";
+
+  g_object_set (path1,
+		"data", data,
+		NULL);
+
+  count = (count + 1) % 3;
+}
+
+
 GtkWidget *
 create_paths_page (void)
 {
-  GtkWidget *vbox, *scrolled_win, *canvas;
+  GtkWidget *vbox, *hbox, *w, *scrolled_win, *canvas;
 
   vbox = gtk_vbox_new (FALSE, 4);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
   gtk_widget_show (vbox);
 
+  hbox = gtk_hbox_new (FALSE, 4);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+  gtk_widget_show (hbox);
+
   scrolled_win = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_win),
 				       GTK_SHADOW_IN);
@@ -119,5 +147,11 @@ create_paths_page (void)
 
   setup_canvas (canvas);
 
+  w = gtk_button_new_with_label ("Move Path");
+  gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
+  gtk_widget_show (w);
+  g_signal_connect (w, "clicked",
+		    (GtkSignalFunc) move_path_clicked, canvas);
+
   return vbox;
 }
