@@ -54,7 +54,8 @@ create_table1 (GooCanvasItem *parent,
 	       gdouble        x,
 	       gdouble        y,
 	       gdouble        width,
-	       gdouble        height)
+	       gdouble        height,
+	       gboolean       with_grid_lines)
 {
   GooCanvasItem *table, *items[9];
   GooCanvasBounds bounds;
@@ -66,6 +67,18 @@ create_table1 (GooCanvasItem *parent,
 				NULL);
   goo_canvas_item_translate (table, x, y);
 
+  if (with_grid_lines)
+    {
+      g_object_set (G_OBJECT (table),
+		    "row-spacing",  2.0,
+		    "column-spacing", 2.0,
+		    "x-border-spacing", 1.0,
+		    "y-border-spacing", 1.0,
+		    "horz-grid-line-width", 1.0,
+		    "vert-grid-line-width", 2.0,
+		    NULL);
+    }
+
   items[i++] = create_item (table, 17.3, 12.9, 0, 0, 1, 1,
 			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
   items[i++] = create_item (table, 33.1, 17.2, 1, 0, 1, 1,
@@ -96,6 +109,66 @@ create_table1 (GooCanvasItem *parent,
     }
 }
 
+/* Creates a table with items spanning multiple cells */
+void
+create_table2 (GooCanvasItem *parent,
+	       gdouble        x,
+	       gdouble        y,
+	       gdouble        width,
+	       gdouble        height,
+	       gboolean       with_grid_lines)
+{
+  GooCanvasItem *table, *items[9];
+  GooCanvasBounds bounds;
+  gint i = 0;
+
+  table = goo_canvas_table_new (parent,
+				"width", width,
+				"height", height,
+				NULL);
+  goo_canvas_item_translate (table, x, y);
+
+  if (with_grid_lines)
+    {
+      g_object_set (G_OBJECT (table),
+		    "row-spacing",  2.0,
+		    "column-spacing", 2.0,
+		    "x-border-spacing", 1.0,
+		    "y-border-spacing", 1.0,
+		    "horz-grid-line-width", 1.0,
+		    "vert-grid-line-width", 2.0,
+		    NULL);
+    }
+
+  items[i++] = create_item (table, 17.3, 12.9, 0, 0, 2, 2,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+  items[i++] = create_item (table, 33.1, 17.2, 0, 2, 1, 1,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+  items[i++] = create_item (table, 41.6, 23.9, 1, 2, 1, 1,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+
+  items[i++] = create_item (table, 7.1, 5.7, 0, 3, 2, 1,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+  items[i++] = create_item (table, 13.5, 18.2, 2, 0, 1, 1,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+  items[i++] = create_item (table, 25.2, 22.1, 2, 1, 1, 3,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+
+  items[i++] = create_item (table, 11.3, 11.7, 3, 0, 1, 1,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+  items[i++] = create_item (table, 21.7, 18.8, 3, 1, 1, 1,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+  items[i++] = create_item (table, 22.2, 13.8, 3, 2, 1, 2,
+			    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE);
+
+  for (i = 0; i < 9; i++)
+    {
+      goo_canvas_item_get_bounds (items[i], &bounds);
+      g_print ("Item %i: %g,%g - %g,%g\n", i,
+	       bounds.x1 - x, bounds.y1 - y,
+	       bounds.x2 - x, bounds.y2 - y);
+    }
+}
 
 void
 setup_canvas (GtkWidget *canvas)
@@ -105,13 +178,31 @@ setup_canvas (GtkWidget *canvas)
   root = goo_canvas_get_root_item (GOO_CANVAS (canvas));
 
   g_print ("\nTable at default size...\n");
-  create_table1 (root, 50, 50, -1, -1);
+  create_table1 (root, 50, 50, -1, -1, FALSE);
 
   g_print ("\nTable at reduced size...\n");
-  create_table1 (root, 250, 50, 30, 30);
+  create_table1 (root, 250, 50, 30, 30, FALSE);
 
   g_print ("\nTable at enlarged size...\n");
-  create_table1 (root, 450, 50, 100, 100);
+  create_table1 (root, 450, 50, 100, 100, FALSE);
+
+  g_print ("\nTable with grid lines at default size...\n");
+  create_table1 (root, 50, 250, -1, -1, TRUE);
+
+  g_print ("\nTable with grid lines at reduced size...\n");
+  create_table1 (root, 250, 250, 30, 30, TRUE);
+
+  g_print ("\nTable with grid lines at enlarged size...\n");
+  create_table1 (root, 450, 250, 150, 150, TRUE);
+
+  g_print ("Multispanning table with grid lines at default size...\n");
+  create_table2 (root, 50, 450, -1, -1, TRUE);
+
+  g_print ("Multispanning table with grid lines at reduced size...\n");
+  create_table2 (root, 250, 450, 30, 30, TRUE);
+
+  g_print ("Multispanning table with grid lines at enlarged size...\n");
+  create_table2 (root, 450, 450, 150, 150, TRUE);
 }
 
 
