@@ -205,7 +205,9 @@ goo_canvas_polyline_finalize (GObject *object)
   GooCanvasItemSimple *simple = (GooCanvasItemSimple*) object;
   GooCanvasPolyline *polyline = (GooCanvasPolyline*) object;
 
-  if (!simple->model)
+  /* Free our data if we didn't have a model. (If we had a model it would
+     have been reset in dispose() and simple_data will be NULL.) */
+  if (simple->simple_data)
     {
       g_slice_free1 (polyline->polyline_data->num_points * 2 * sizeof (gdouble),
 		     polyline->polyline_data->coords);
@@ -385,9 +387,8 @@ static void
 goo_canvas_polyline_reconfigure_arrows (GooCanvasPolyline *polyline)
 {
   GooCanvasItemSimple *simple = (GooCanvasItemSimple*) polyline;
-  GooCanvasItemSimpleData *simple_data = simple->simple_data;
   GooCanvasPolylineData *polyline_data = polyline->polyline_data;
-  double line_width = 2.0;
+  double line_width;
 
   if (!polyline_data->reconfigure_arrows)
     return;
@@ -398,20 +399,7 @@ goo_canvas_polyline_reconfigure_arrows (GooCanvasPolyline *polyline)
       || (!polyline_data->start_arrow && !polyline_data->end_arrow))
     return;
 
-  /* Determine the item's line width setting, either the default canvas line
-     width or the item style's line width setting. */
-  if (simple->canvas)
-    line_width = goo_canvas_get_default_line_width (simple->canvas);
-  if (simple_data->style)
-    {
-      GValue *value;
-
-      value = goo_canvas_style_get_property (simple_data->style,
-					     goo_canvas_style_line_width_id);
-      if (value)
-	line_width = value->data[0].v_double;
-    }
-
+  line_width = goo_canvas_item_simple_get_line_width (simple);
   ensure_arrow_data (polyline_data);
 
   if (polyline_data->start_arrow)
@@ -761,39 +749,32 @@ goo_canvas_polyline_create_end_arrow_path (GooCanvasPolyline *polyline,
 }
 
 
-static GooCanvasItem*
-goo_canvas_polyline_get_item_at (GooCanvasItemSimple *simple,
-				 gdouble              x,
-				 gdouble              y,
-				 cairo_t             *cr,
-				 gboolean             is_pointer_event)
+static gboolean
+goo_canvas_polyline_is_item_at (GooCanvasItemSimple *simple,
+				gdouble              x,
+				gdouble              y,
+				cairo_t             *cr,
+				gboolean             is_pointer_event)
 {
   GooCanvasItemSimpleData *simple_data = simple->simple_data;
   GooCanvasPolyline *polyline = (GooCanvasPolyline*) simple;
   GooCanvasPolylineData *polyline_data = polyline->polyline_data;
-  GooCanvasItem *found_item = NULL;
   GooCanvasPointerEvents pointer_events = GOO_CANVAS_EVENTS_ALL;
   gboolean do_stroke;
-  cairo_matrix_t matrix;
 
   if (polyline_data->num_points == 0)
-    return NULL;
+    return FALSE;
 
   /* Check if the item should receive events. */
   if (is_pointer_event)
     pointer_events = simple_data->pointer_events;
 
-  /* Remove any current translation, to avoid the 16-bit cairo limit. */
-  cairo_get_matrix (cr, &matrix);
-  matrix.x0 = matrix.y0 = 0.0;
-  cairo_set_matrix (cr, &matrix);
-
   goo_canvas_polyline_create_path (polyline, cr);
   if (goo_canvas_item_simple_check_in_path (simple, x, y, cr, pointer_events))
-    found_item = (GooCanvasItem*) simple;
+    return TRUE;
 
   /* Check the arrows, if the polyline has them. */
-  if (!found_item && (polyline_data->start_arrow || polyline_data->end_arrow)
+  if ((polyline_data->start_arrow || polyline_data->end_arrow)
       && polyline_data->num_points >= 2
       && (pointer_events & GOO_CANVAS_EVENTS_STROKE_MASK))
     {
@@ -805,19 +786,19 @@ goo_canvas_polyline_get_item_at (GooCanvasItemSimple *simple,
 	    {
 	      goo_canvas_polyline_create_start_arrow_path (polyline, cr);
 	      if (cairo_in_fill (cr, x, y))
-		found_item = (GooCanvasItem*) simple;
+		return TRUE;
 	    }
 
-	  if (!found_item && polyline_data->end_arrow)
+	  if (polyline_data->end_arrow)
 	    {
 	      goo_canvas_polyline_create_end_arrow_path (polyline, cr);
 	      if (cairo_in_fill (cr, x, y))
-		found_item = (GooCanvasItem*) simple;
+		return TRUE;
 	    }
 	}
     }
 
-  return found_item;
+  return FALSE;
 }
 
 
@@ -895,9 +876,9 @@ goo_canvas_polyline_update  (GooCanvasItemSimple *simple,
 
 
 static void
-goo_canvas_polyline_paint (GooCanvasItemSimple *simple,
-			   cairo_t             *cr,
-			   GooCanvasBounds     *bounds)
+goo_canvas_polyline_paint (GooCanvasItemSimple   *simple,
+			   cairo_t               *cr,
+			   const GooCanvasBounds *bounds)
 {
   GooCanvasItemSimpleData *simple_data = simple->simple_data;
   GooCanvasPolyline *polyline = (GooCanvasPolyline*) simple;
@@ -964,14 +945,14 @@ goo_canvas_polyline_class_init (GooCanvasPolylineClass *klass)
   GObjectClass *gobject_class = (GObjectClass*) klass;
   GooCanvasItemSimpleClass *simple_class = (GooCanvasItemSimpleClass*) klass;
 
-  gobject_class->finalize = goo_canvas_polyline_finalize;
+  gobject_class->finalize  = goo_canvas_polyline_finalize;
 
   gobject_class->get_property = goo_canvas_polyline_get_property;
   gobject_class->set_property = goo_canvas_polyline_set_property;
 
   simple_class->simple_update        = goo_canvas_polyline_update;
   simple_class->simple_paint         = goo_canvas_polyline_paint;
-  simple_class->simple_get_item_at   = goo_canvas_polyline_get_item_at;
+  simple_class->simple_is_item_at    = goo_canvas_polyline_is_item_at;
 
   goo_canvas_polyline_install_common_properties (gobject_class);
 }
