@@ -308,6 +308,23 @@ goo_cairo_line_join_get_type (void)
 }
 
 
+GType
+goo_cairo_hint_metrics_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CAIRO_HINT_METRICS_DEFAULT, "CAIRO_HINT_METRICS_DEFAULT", "default" },
+      { CAIRO_HINT_METRICS_OFF, "CAIRO_HINT_METRICS_OFF", "off" },
+      { CAIRO_HINT_METRICS_ON, "CAIRO_HINT_METRICS_ON", "on" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GooCairoHintMetrics", values);
+  }
+  return etype;
+}
+
+
 /**
  * goo_canvas_line_dash_ref:
  * @dash: a #GooCanvasLineDash.
@@ -418,20 +435,27 @@ goo_canvas_line_dash_newv (gint    num_dashes,
 }
 
 cairo_matrix_t*
-goo_cairo_matrix_copy   (cairo_matrix_t *matrix)
+goo_cairo_matrix_copy   (const cairo_matrix_t *matrix)
 {
   cairo_matrix_t *matrix_copy;
 
   if (!matrix)
     return NULL;
 
-  matrix_copy = g_new (cairo_matrix_t, 1);
+  matrix_copy = g_slice_new (cairo_matrix_t);
   *matrix_copy = *matrix;
 
   return matrix_copy;
 }
 
 
+void
+goo_cairo_matrix_free   (cairo_matrix_t *matrix)
+{
+  g_slice_free (cairo_matrix_t, matrix);
+}
+
+
 GType
 goo_cairo_matrix_get_type (void)
 {
@@ -441,7 +465,7 @@ goo_cairo_matrix_get_type (void)
     type_cairo_matrix = g_boxed_type_register_static
       ("GooCairoMatrix", 
        (GBoxedCopyFunc) goo_cairo_matrix_copy,
-       (GBoxedFreeFunc) g_free);
+       (GBoxedFreeFunc) goo_cairo_matrix_free);
 
   return type_cairo_matrix;
 }
@@ -1126,5 +1150,45 @@ goo_canvas_create_path (GArray              *commands,
 }
 
 
+/* This is a copy of _gtk_boolean_handled_accumulator. */
+gboolean
+goo_canvas_boolean_handled_accumulator (GSignalInvocationHint *ihint,
+					GValue                *return_accu,
+					const GValue          *handler_return,
+					gpointer               dummy)
+{
+  gboolean continue_emission;
+  gboolean signal_handled;
+  
+  signal_handled = g_value_get_boolean (handler_return);
+  g_value_set_boolean (return_accu, signal_handled);
+  continue_emission = !signal_handled;
+  
+  return continue_emission;
+}
+
+
+static GooCanvasBounds *
+goo_canvas_bounds_copy (const GooCanvasBounds *bounds)
+{
+  GooCanvasBounds *result = g_new (GooCanvasBounds, 1);
+  *result = *bounds;
+
+  return result;
+}
+
+GType
+goo_canvas_bounds_get_type (void)
+{
+  static GType our_type = 0;
+  
+  if (our_type == 0)
+    our_type = g_boxed_type_register_static
+      ("GooCanvasBounds",
+       (GBoxedCopyFunc) goo_canvas_bounds_copy,
+       (GBoxedFreeFunc) g_free);
+
+  return our_type;
+}
 
 
